@@ -472,9 +472,10 @@ class GPsep(BaseEstimator, RegressorMixin):
         if verbosity > 0:
             print(f"X shape: {X.shape}, y shape: {y.shape}")
         if self.max_points is not None:
-            X, y = select_distant_points(X, y, self.max_points)
-            if verbosity > 0:
-                print(f"Selected {self.max_points} points for the model.")
+            if X.shape[0] > self.max_points:
+                X, y = select_distant_points(X, y, self.max_points)
+                if verbosity > 0:
+                    print(f"Selected {self.max_points} points for the model.")
         if auto_optimize is None:
             auto_optimize = self.auto_optimize
         n, m = X.shape
@@ -666,7 +667,10 @@ class GPsep(BaseEstimator, RegressorMixin):
         #     raise RuntimeError("Covariance matrix has already been built.")
         self.K = covar_anisotropic(self.X, d=self.d, g=self.g)
         self.Ki = matrix_inversion_dispatcher(self.K, method=self.nlsep_method)
-        self.ldetK = np.log(det(self.K))
+        detK = det(self.K)
+        if detK <= 1e-14:
+            detK = 1e-14  # TODO: Check if this can be improved
+        self.ldetK = np.log(detK)
         self.calc_ytKiy()
         # TODO: Check if this is necessary
         # if self.dK:
